@@ -3,9 +3,6 @@ package Perlanet::Feed;
 use strict;
 use warnings;
 
-use 5.6.0;
-our $VERSION = '0.58';
-
 use Moose;
 use XML::Feed;
 
@@ -82,7 +79,8 @@ Returns a string containing the XML for this feed and all its entries
 =cut
 
 sub as_xml {
-  my ($self, $format) = @_;
+  my $self = shift;
+  my ($format) = @_;
 
   my $feed = XML::Feed->new($format);
   $feed->title($self->title);
