@@ -3,9 +3,6 @@ package Perlanet::Trait::Tidy;
 use strict;
 use warnings;
 
-use 5.6.0;
-our $VERSION = '0.58';
-
 use Moose::Role;
 use namespace::autoclean;
 
@@ -71,7 +68,8 @@ sub _build_tidy {
 
 around 'clean_html' => sub {
   my $orig = shift;
-  my ($self, $html) = @_;
+  my $self = shift;
+  my ($html) = @_;
 
   $html = $self->$orig($html);
 
